We had a "bug" in our previous benchmark ("mspw_bench.sql"). The way it
was written allowed SQLite to short-circuit column data retrieval,
ending up with minimal exercising of the CFFI layer.
The attached query exercises CFFI as it should. We also checked its
profiling characteristics, and it is a lot closer to what we are seen
with our working query loads.
Below are timings when running it from inside mterm (so there is no
import overhead):
CPython + APSW: 0 sec 956 msec
pypy + APSW: 8 sec 673 msec
pypy + MSPW: 2 sec 550 msec
Best regards.
lefteris.
select count(*) from (rowidvt select textwindow(t,10 ,10) from (select concatterms(hashmd5(c1)) as t from range(25000)));
_______________________________________________
pypy-dev mailing list
[email protected]
http://mail.python.org/mailman/listinfo/pypy-dev